#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  database
Name:           octave-forge-%{octpkg}
Version:        2.4.4
Release:        3.5
Summary:        Octave plugin interfacing PostgreSQL
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         add_missing_iostream_include.patch
# PATCH-FIX-OPENSUSE -- boo#1120035, pg_config is no longer in the postgresql-devel package, use pkg-config instead
Patch1:         0001-Use-pkg-config-instead-of-pg_config.patch
# PATCH-FIX-UPSTREAM database-drop-error_state.patch badshah400@gmail.com -- Drop error_state for octave >= 8 compatibility (https://savannah.gnu.org/bugs/index.php?61567)
Patch2:         database-drop-error_state.patch
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel >= 4.0.0
BuildRequires:  pkg-config
BuildRequires:  postgresql-devel >= 8.3
Requires:       octave-cli >= 4.0.0
Requires:       octave-forge-struct >= 1.0.12

%description
Interface to PostgreSQL databases.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
pushd %{octpkg}-%{version}
%autopatch -p1
popd
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Wed Apr 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add database-drop-error_state.patch -- Drop error_state usage
  for octave >= 8 compatibility
  (https://savannah.gnu.org/bugs/index.php?61567).
* Wed Oct 26 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update 0001-Use-pkg-config-instead-of-pg_config.patch: simplify
  by using pkg-config --atleast-version instead of trying to awk
  over the --modversion output. Happens to fix build with pgsql
  15rc2.
* Mon Nov 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.4.4
  * Build fixes. Builds with Octave 5.1.
  * Works now also with a postgresql server owned by a different user
    than postgres
- Rebase add_missing_iostream_include.patch
* Fri Mar 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add fix required after SUSE packaging change, boo#1120035
  0001-Use-pkg-config-instead-of-pg_config.patch
* Tue Mar  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix compilation with current GCC, add add_missing_iostream_include.patch
* Wed Aug  8 2018 jengelh@inai.de
- Compact descriptions.
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 2.4.3:
  * Octave 4.4 compatibility.
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Bug fixes.
  * Octave 4.2 compatibility.
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 2.4.1
  * Added general package documentation.
  * New functions var2bytea and bytea2var, enabling storing Octave
    values of arbitrary type in a database.
  * Compatible with Octaves new exception-based error
    handling.
* Wed May  6 2015 dmitry_r@opensuse.org
- Update to version 2.3.2
  * Fix a potential source of internal bugs.
  * Incompatible versions of postgresql (< 8.3) are rejected at
    configure time.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.3.1
